@@ -23,6 +23,7 @@ from zope.interface.interfaces import IInterface
 
 from zope.schema._bootstrapfields import Bool
 from zope.schema._bootstrapfields import Complex
+from zope.schema._bootstrapfields import Decimal
 from zope.schema._bootstrapfields import Field
 from zope.schema._bootstrapfields import Int
 from zope.schema._bootstrapfields import Integral
@@ -462,7 +463,8 @@ class INativeStringLine(ITextLine if PY3 else IBytesLine):
 
 
 class IPassword(ITextLine):
-    "Field containing a unicode string without newlines that is a password."
+    """Field containing a unicode password string without newlines."""
+
 
 ###
 # Numbers
@@ -549,6 +551,7 @@ class IReal(IComplex):
                         field value""")
         )
 
+
 class IRational(IReal):
     """
     Field containing a rational number: :class:`numbers.IRational`.
@@ -575,6 +578,7 @@ class IRational(IReal):
                         field value""")
         )
 
+
 class IIntegral(IRational):
     """
     Field containing an integral number: class:`numbers.Integral`.
@@ -599,6 +603,8 @@ class IIntegral(IRational):
         description=_("""The field default value may be None or a legal
                         field value""")
         )
+
+
 ##
 # Concrete numbers
 ##
@@ -644,10 +650,29 @@ class IFloat(IReal):
 class IDecimal(INumber):
     """Field containing a :class:`decimal.Decimal`"""
 
+    min = Decimal(
+        title=_("Start of the range"),
+        required=False,
+        default=None
+        )
+
+    max = Decimal(
+        title=_("End of the range (including the value itself)"),
+        required=False,
+        default=None
+        )
+
+    default = Decimal(
+        title=_("Default Value"),
+        description=_("""The field default value may be None or a legal
+                        field value""")
+        )
+
 ###
 # End numbers
 ###
 
+
 class IDatetime(IMinMax, IField):
     """Field containing a datetime."""
 
@@ -738,6 +763,7 @@ class IChoice(IField):
         default=None
         )
 
+
 # Collections:
 
 # Abstract
@@ -773,6 +799,7 @@ class IMutableSequence(ISequence):
     .. versionadded:: 4.6.0
     """
 
+
 class IUnorderedCollection(ICollection):
     """Abstract interface specifying that the value cannot be ordered"""
 
@@ -780,14 +807,16 @@ class IUnorderedCollection(ICollection):
 class IAbstractSet(IUnorderedCollection):
     """An unordered collection of unique values."""
 
-    unique = Bool(description="This ICollection interface attribute must be True")
+    unique = Bool(
+        description="This ICollection interface attribute must be True")
 
 
 class IAbstractBag(IUnorderedCollection):
     """An unordered collection of values, with no limitations on whether
     members are unique"""
 
-    unique = Bool(description="This ICollection interface attribute must be False")
+    unique = Bool(
+        description="This ICollection interface attribute must be False")
 
 
 # Concrete
@@ -825,18 +854,19 @@ class IObject(IField):
 
     schema = Object(
         IInterface,
-        description=_("The Interface that defines the Fields comprising the Object.")
+        description=_("The Interface that defines the Fields comprising the "
+                      "Object.")
     )
 
     validate_invariants = Bool(
         title=_("Validate Invariants"),
-        description=_("A boolean that says whether ``schema.validateInvariants`` "
-                      "is called from ``self.validate()``. The default is true."),
+        description=_("A boolean that says whether "
+                      "``schema.validateInvariants`` is called from "
+                      "``self.validate()``. The default is true."),
         default=True,
     )
 
 
-
 class IMapping(IMinMaxLen, IIterable, IContainer):
     """
     Field containing an instance of :class:`collections.Mapping`.
@@ -847,7 +877,8 @@ class IMapping(IMinMaxLen, IIterable, IContainer):
     """
     key_type = Object(
         IField,
-        description=_("Field keys must conform to the given type, expressed via a Field.")
+        description=_("Field keys must conform to the given type, expressed "
+                      "via a Field.")
     )
 
     value_type = Object(
