@@ -13,15 +13,19 @@
 ##############################################################################
 """Vocabulary support for schema.
 """
+from collections import OrderedDict
 
 from zope.interface import directlyProvides
 from zope.interface import implementer
+from zope.interface import providedBy
+
+from zope.schema._compat import text_type
 from zope.schema.interfaces import ITitledTokenizedTerm
 from zope.schema.interfaces import ITokenizedTerm
 from zope.schema.interfaces import ITreeVocabulary
 from zope.schema.interfaces import IVocabularyRegistry
 from zope.schema.interfaces import IVocabularyTokenized
-from collections import OrderedDict
+
 
 # simple vocabularies performing enumerated-like tasks
 _marker = object()
@@ -29,30 +33,75 @@ _marker = object()
 
 @implementer(ITokenizedTerm)
 class SimpleTerm(object):
-    """Simple tokenized term used by SimpleVocabulary."""
+    """
+    Simple tokenized term used by SimpleVocabulary.
+
+    .. versionchanged:: 4.6.0
+       Implement equality and hashing based on the value, token and title.
+    """
 
     def __init__(self, value, token=None, title=None):
-        """Create a term for value and token. If token is omitted,
-        str(value) is used for the token.  If title is provided,
-        term implements ITitledTokenizedTerm.
+        """Create a term for *value* and *token*. If *token* is
+        omitted, str(value) is used for the token, escaping any
+        non-ASCII characters.
+
+        If *title* is provided, term implements
+        :class:`zope.schema.interfaces.ITitledTokenizedTerm`.
         """
         self.value = value
         if token is None:
             token = value
         # In Python 3 str(bytes) returns str(repr(bytes)), which is not what
         # we want here. On the other hand, we want to try to keep the token as
-        # readable as possible.
-        self.token = str(token) \
-            if not isinstance(token, bytes) \
-            else str(token.decode('ascii', 'ignore'))
+        # readable as possible. On both 2 and 3, self.token should be a native
+        # string (ASCIILine).
+        if isinstance(token, bytes):
+            token = token.decode('raw_unicode_escape')
+        elif not isinstance(token, (str, text_type)):
+            # Nothing we recognize as intended to be textual data.
+            # Get its str() as promised
+            token = str(token)
+
+        if isinstance(token, text_type):  # pragma: PY2
+            token = token.encode('ascii', 'backslashreplace')
+        # Token should be bytes at this point. Now back to native string,
+        # if needed.
+        if not isinstance(token, str):    # pragma: PY2
+            token = token.decode('ascii')
+        self.token = token
         self.title = title
         if title is not None:
             directlyProvides(self, ITitledTokenizedTerm)
 
+    def __eq__(self, other):
+        if other is self:
+            return True
+
+        if not isinstance(other, SimpleTerm):
+            return False
+
+        return (
+            self.value == other.value
+            and self.token == other.token
+            and self.title == other.title
+        )
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    def __hash__(self):
+        return hash((self.value, self.token, self.title))
+
 
 @implementer(IVocabularyTokenized)
 class SimpleVocabulary(object):
-    """Vocabulary that works from a sequence of terms."""
+    """
+    Vocabulary that works from a sequence of terms.
+
+    .. versionchanged:: 4.6.0
+       Implement equality and hashing based on the terms list
+       and interfaces implemented by this object.
+    """
 
     def __init__(self, terms, *interfaces, **kwargs):
         """Initialize the vocabulary given a list of terms.
@@ -65,14 +114,14 @@ class SimpleVocabulary(object):
 
         By default, ValueErrors are thrown if duplicate values or tokens
         are passed in. If you want to swallow these exceptions, pass
-        in swallow_duplicates=True. In this case, the values will
+        in ``swallow_duplicates=True``. In this case, the values will
         override themselves.
         """
         self.by_value = {}
         self.by_token = {}
         self._terms = terms
+        swallow_dupes = kwargs.get('swallow_duplicates', False)
         for term in self._terms:
-            swallow_dupes = kwargs.get('swallow_duplicates', False)
             if not swallow_dupes:
                 if term.value in self.by_value:
                     raise ValueError(
@@ -87,16 +136,23 @@ class SimpleVocabulary(object):
 
     @classmethod
     def fromItems(cls, items, *interfaces):
-        """Construct a vocabulary from a list of (token, value) pairs.
+        """
+        Construct a vocabulary from a list of (token, value) pairs or
+        (token, value, title) triples. The list does not have to be
+        homogeneous.
 
         The order of the items is preserved as the order of the terms
-        in the vocabulary.  Terms are created by calling the class
-        method createTerm() with the pair (value, token).
+        in the vocabulary. Terms are created by calling the class
+        method :meth:`createTerm`` with the pair or triple.
 
         One or more interfaces may also be provided so that alternate
         widgets may be bound without subclassing.
+
+        .. versionchanged:: 4.6.0
+            Allow passing in triples to set item titles.
         """
-        terms = [cls.createTerm(value, token) for (token, value) in items]
+        terms = [cls.createTerm(item[1], item[0], *item[2:])
+                 for item in items]
         return cls(terms, *interfaces)
 
     @classmethod
@@ -104,10 +160,10 @@ class SimpleVocabulary(object):
         """Construct a vocabulary from a simple list.
 
         Values of the list become both the tokens and values of the
-        terms in the vocabulary.  The order of the values is preserved
-        as the order of the terms in the vocabulary.  Tokens are
-        created by calling the class method createTerm() with the
-        value as the only parameter.
+        terms in the vocabulary. The order of the values is preserved
+        as the order of the terms in the vocabulary. Tokens are
+        created by calling the class method :meth:`createTerm()` with
+        the value as the only parameter.
 
         One or more interfaces may also be provided so that alternate
         widgets may be bound without subclassing.
@@ -154,6 +210,24 @@ class SimpleVocabulary(object):
         """See zope.schema.interfaces.IIterableVocabulary"""
         return len(self.by_value)
 
+    def __eq__(self, other):
+        if other is self:
+            return True
+
+        if not isinstance(other, SimpleVocabulary):
+            return False
+
+        return (
+            self._terms == other._terms
+            and providedBy(self) == providedBy(other)
+        )
+
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
+    def __hash__(self):
+        return hash(tuple(self._terms))
+
 
 def _createTermTree(ttree, dict_):
     """ Helper method that creates a tree-like dict with ITokenizedTerm
@@ -162,7 +236,7 @@ def _createTermTree(ttree, dict_):
     See fromDict for more details.
     """
     for key in sorted(dict_.keys()):
-        term = SimpleTerm(key[1], key[0], key[-1])
+        term = SimpleTerm(key[1], key[0], *key[2:])
         ttree[term] = TreeVocabulary.terms_factory()
         _createTermTree(ttree[term], dict_[key])
     return ttree
@@ -257,11 +331,13 @@ class TreeVocabulary(object):
         OrderedDict), that has tuples for keys.
 
         The tuples should have either 2 or 3 values, i.e:
-        (token, value, title) or (token, value)
+        (token, value, title) or (token, value). Only tuples that have
+        three values will create a
+        :class:`zope.schema.interfaces.ITitledTokenizedTerm`.
 
-        For example, a dict with 2-valued tuples:
+        For example, a dict with 2-valued tuples::
 
-        dict_ = {
+          dict_ = {
             ('exampleregions', 'Regions used in ATVocabExample'): {
                 ('aut', 'Austria'): {
                     ('tyr', 'Tyrol'): {
@@ -272,9 +348,14 @@ class TreeVocabulary(object):
                     ('bav', 'Bavaria'):{}
                 },
             }
-        }
+          }
+
         One or more interfaces may also be provided so that alternate
         widgets may be bound without subclassing.
+
+        .. versionchanged:: 4.6.0
+           Only create ``ITitledTokenizedTerm`` when a title is actually
+           provided.
         """
         return cls(_createTermTree(cls.terms_factory(), dict_), *interfaces)
 
@@ -301,7 +382,7 @@ class TreeVocabulary(object):
             self.term_by_value[value] = term
             self.term_by_token[token] = term
 
-            if value not in self.path_by_value:
+            if value not in self.path_by_value:  # pragma: no branch
                 self.path_by_value[value] = self._getPathToTreeNode(self,
                                                                     value)
             self._populateIndexes(tree[term])
@@ -347,9 +428,15 @@ class TreeVocabulary(object):
 
 # registry code
 class VocabularyRegistryError(LookupError):
+    """
+    A specialized subclass of `LookupError` raised for unknown
+    (unregistered) vocabularies.
+
+    .. seealso:: `VocabularyRegistry`
+    """
     def __init__(self, name):
         self.name = name
-        Exception.__init__(self, str(self))
+        super(VocabularyRegistryError, self).__init__(str(self))
 
     def __str__(self):
         return "unknown vocabulary: %r" % self.name
@@ -357,22 +444,40 @@ class VocabularyRegistryError(LookupError):
 
 @implementer(IVocabularyRegistry)
 class VocabularyRegistry(object):
-    __slots__ = '_map',
+    """
+    Default implementation of
+    :class:`zope.schema.interfaces.IVocabularyRegistry`.
+
+    An instance of this class is used by default by
+    :func:`getVocabularyRegistry`, which in turn is used by
+    :class:`~.Choice` fields.
+
+    Named vocabularies must be manually registered with this object
+    using :meth:`register`. This associates a vocabulary name with a
+    :class:`zope.schema.interfaces.IVocabularyFactory`.
+
+    An alternative to this is to use the :mod:`zope.component` registry via
+    `zope.vocabularyregistry
+    <https://pypi.org/project/zope.vocabularyregistry/>`_.
+    """
+    __slots__ = ('_map',)
 
     def __init__(self):
         self._map = {}
 
-    def get(self, object, name):
+    def get(self, context, name):
         """See zope.schema.interfaces.IVocabularyRegistry"""
         try:
             vtype = self._map[name]
         except KeyError:
             raise VocabularyRegistryError(name)
-        return vtype(object)
+        return vtype(context)
 
     def register(self, name, factory):
+        """Register a *factory* for the vocabulary with the given *name*."""
         self._map[name] = factory
 
+
 _vocabularies = None
 
 
